Mount options for partitions and LVM volumes

Mount options for partitions and LVM volumes
Related-Prod: PROD-35384

Change-Id: I0a6cada017f46cb6f5feca0bb2e3205b4e0b062e
diff --git a/_states/maasng.py b/_states/maasng.py
index 5c68652..f309986 100644
--- a/_states/maasng.py
+++ b/_states/maasng.py
@@ -229,10 +229,13 @@
         LOG.info(part)
         if "mount" not in part:
             part["mount"] = None
+        if "mount_options" not in part:
+            part["mount_options"] = None
         if "type" not in part:
             part["type"] = None
         ret["changes"] = __salt__['maasng.create_partition'](
-            hostname, name, part["size"], part["type"], part["mount"])
+            hostname, name, part["size"], part["type"], part["mount"], 
+            part["mount_options"])
 
     if "error" in ret["changes"]:
         ret["result"] = False
@@ -290,7 +293,7 @@
 
 
 def volume_present(hostname, name, volume_group_name, size, type=None,
-                   mount=None):
+                   mount=None, mount_options=None):
     """
     Ensure that the disk layout does exist
 
@@ -326,7 +329,7 @@
     # TODO validation if exists
 
     ret["changes"] = __salt__['maasng.create_volume'](
         hostname, name, volume_group_name, size, type, mount)
 
     return ret
@@ -326,7 +329,7 @@
 
     ret["changes"] = __salt__['maasng.create_volume'](
-        hostname, name, volume_group_name, size, type, mount)
+        hostname, name, volume_group_name, size, type, mount, mount_options)
 
     return ret